pub enum DeclarationSnapshotError {
Key(StableKeyError),
SchemaMetadata(SchemaMetadataError),
DuplicateStableKey(StableKey),
DuplicateSlot(AllocationSlotDescriptor),
}Expand description
DeclarationSnapshotError
Declaration snapshot validation failure.
Variants
Key(StableKeyError)
Stable-key grammar failure.
SchemaMetadata(SchemaMetadataError)
Schema metadata encoding failure.
DuplicateStableKey(StableKey)
A stable key appeared more than once in one snapshot.
DuplicateSlot(AllocationSlotDescriptor)
An allocation slot appeared more than once in one snapshot.