pub enum DiagnosticStableCellStatus {
Empty,
Readable,
Corrupt,
}Expand description
DiagnosticStableCellStatus
Stable-cell ledger storage status.
Variants
Empty
The ledger memory is empty and can be initialized.
Readable
The stable-cell envelope and ledger record decoded successfully.
Corrupt
The ledger memory is present but could not be decoded as the expected stable-cell ledger record.