pub struct DiagnosticRangeAuthority {
pub registered_records: Vec<MemoryManagerAuthorityRecord>,
pub effective_authority: Option<MemoryManagerRangeAuthority>,
pub error: Option<String>,
}Expand description
DiagnosticRangeAuthority
Read-only diagnostic view of registered and effective range authority.
Fields
registered_records: Vec<MemoryManagerAuthorityRecord>Range records registered directly by linked crates.
Effective range authority table, including runtime-owned internal records, when the table validated successfully.
error: Option<String>Validation error when the effective authority table could not be built.
Implementations
Sourceimpl DiagnosticRangeAuthority
impl DiagnosticRangeAuthority
Sourcepub const fn new(
registered_records: Vec<MemoryManagerAuthorityRecord>,
effective_authority: Option<MemoryManagerRangeAuthority>,
error: Option<String>,
) -> Self
pub const fn new( registered_records: Vec<MemoryManagerAuthorityRecord>, effective_authority: Option<MemoryManagerRangeAuthority>, error: Option<String>, ) -> Self
Build a range-authority diagnostic.