#[non_exhaustive]pub enum AllocationReservationError {
Integrity(LedgerIntegrityError),
GenerationOverflow {
generation: u64,
},
TooManyReservations {
count: usize,
},
StableKeySlotConflict {
stable_key: StableKey,
historical_slot: MemoryManagerSlot,
reserved_slot: MemoryManagerSlot,
},
SlotStableKeyConflict {
slot: MemoryManagerSlot,
historical_key: StableKey,
reserved_key: StableKey,
},
ActiveAllocation {
stable_key: StableKey,
slot: MemoryManagerSlot,
},
RetiredAllocation {
stable_key: StableKey,
slot: MemoryManagerSlot,
},
}Expand description
AllocationReservationError
Failure to stage a reservation generation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Integrity(LedgerIntegrityError)
GenerationOverflow
Ledger generation cannot be advanced without overflow.
TooManyReservations
Reservation count exceeds the usable allocation-slot domain.
StableKeySlotConflict
Stable key was historically bound to a different slot.
Fields

historical_slot: MemoryManagerSlotHistorical slot for the stable key.

reserved_slot: MemoryManagerSlotSlot claimed by the reservation.
SlotStableKeyConflict
Slot was historically bound to a different stable key.
Fields

slot: MemoryManagerSlotSlot being reserved.
ActiveAllocation
Allocation already exists as an active record.
RetiredAllocation
Allocation was already retired and cannot be reserved.