#[non_exhaustive]pub enum AllocationStageError {
Integrity(LedgerIntegrityError),
StaleValidatedAllocations {
validated_generation: u64,
ledger_generation: u64,
},
StableKeySlotConflict {
stable_key: StableKey,
historical_slot: AllocationSlotDescriptor,
declared_slot: AllocationSlotDescriptor,
},
SlotStableKeyConflict {
slot: AllocationSlotDescriptor,
historical_key: StableKey,
declared_key: StableKey,
},
RetiredAllocation {
stable_key: StableKey,
slot: AllocationSlotDescriptor,
},
}Expand description
AllocationStageError
Failure to stage a validated allocation generation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Integrity(LedgerIntegrityError)
StaleValidatedAllocations
Validated declarations were produced against a different ledger generation.
Fields
StableKeySlotConflict
Stable key was historically bound to a different slot.
Fields

historical_slot: AllocationSlotDescriptorHistorical slot for the stable key.

declared_slot: AllocationSlotDescriptorSlot claimed by the declaration.
SlotStableKeyConflict
Slot was historically bound to a different stable key.
Fields

slot: AllocationSlotDescriptorSlot being declared.
RetiredAllocation
Current declaration attempted to revive a retired allocation.
Fields

slot: AllocationSlotDescriptorRetired allocation slot.