pub enum DiagnosticCode {
StableCell,
UnsupportedFormat,
LedgerRecovery,
AllocationValidation,
PolicyIdentity,
RuntimeBinding,
}Expand description
DiagnosticCode
Stable machine-readable category for an operator diagnostic failure.
Variants
StableCell
Stable-cell storage could not be decoded.
UnsupportedFormat
Persisted bytes use a recognized but unsupported durable format.
LedgerRecovery
Protected ledger recovery failed.
AllocationValidation
Current declarations failed allocation validation.
PolicyIdentity
Runtime bootstrap policy identity was invalid.
RuntimeBinding
Tested bootstrap identity or declarations differ from runtime state.