#[non_exhaustive]pub enum LedgerIntegrityError {
LimitExceeded {
resource: &'static str,
limit: usize,
},
DuplicateStableKey {
stable_key: StableKey,
},
DuplicateSlot {
slot: MemoryManagerSlot,
},
NonemptyGenesis,
}Expand description
LedgerIntegrityError
Decoded ledger violates current ownership invariants.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LimitExceeded
Current structural recovery ceiling exceeded.
DuplicateStableKey
Stable key appears in more than one retained allocation record.
DuplicateSlot
Memory ID appears in more than one retained allocation record.
Fields

slot: MemoryManagerSlotNonemptyGenesis
Commit counter zero is reserved for empty genesis.