#[non_exhaustive]pub enum MemoryManagerLayoutError {
UnsupportedByteOrder,
ZeroBucketSize,
ReservedHeader,
BucketCount {
count: u16,
},
BucketTable {
index: u16,
},
VirtualExtent {
id: u8,
},
TruncatedBacking {
physical_pages: u64,
required_pages: u64,
},
ExtentOverflow,
RuntimeMismatch,
}Expand description
MemoryManagerLayoutError
Invalid or unsupported persisted manager metadata. No writes are performed
when reporting these failures. Memory implementations must obey Memory.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedByteOrder
This adapter supports the little-endian IC/current native layout only.
ZeroBucketSize
The persisted bucket size is zero.
ReservedHeader
Reserved header fields are not recognized by this adapter.
BucketCount
The allocated count exceeds the finite bucket table.
BucketTable
Allocated buckets must be a dense prefix and all later entries unused.
VirtualExtent
Virtual extent disagrees with the number of assigned buckets.
TruncatedBacking
Backing memory does not cover every assigned bucket.
ExtentOverflow
Backing size cannot be represented in bytes.
RuntimeMismatch
A live manager’s cached state differs from persisted metadata.