LedgerCommitError

Enum LedgerCommitError 

pub enum LedgerCommitError {
    Recovery(CommitRecoveryError),
    PayloadEnvelope(LedgerPayloadEnvelopeError),
    UnsupportedEnvelopeVersion {
        found: u16,
        supported: u16,
    },
    PhysicalLogicalGenerationMismatch {
        physical_generation: u64,
        logical_generation: u64,
    },
    PayloadEnvelopeLedgerMismatch {
        envelope_ledger_schema_version: u32,
        ledger_schema_version: u32,
        envelope_physical_format_id: u32,
        ledger_physical_format_id: u32,
    },
    Codec(String),
    Compatibility(LedgerCompatibilityError),
    Integrity(LedgerIntegrityError),
}
LedgerCommitError

Failure to recover or commit a logical allocation ledger.

Variants



Recovery(CommitRecoveryError)

Protected physical commit recovery failed.



PayloadEnvelope(LedgerPayloadEnvelopeError)

Logical ledger payload envelope could not be decoded.



UnsupportedEnvelopeVersion

Logical ledger payload envelope version is unsupported.

Fields

found: u16

Version found in the envelope.

supported: u16

Supported version.



PhysicalLogicalGenerationMismatch

Physical slot generation and decoded logical ledger generation disagree.

Fields

physical_generation: u64

Generation encoded in the physical commit slot.

logical_generation: u64

Generation decoded from the logical allocation ledger.



PayloadEnvelopeLedgerMismatch

Logical payload envelope and decoded ledger headers disagree.

Fields

envelope_ledger_schema_version: u32

Schema version declared by the envelope.

ledger_schema_version: u32

Schema version decoded from the ledger.

envelope_physical_format_id: u32

Physical format ID declared by the envelope.

ledger_physical_format_id: u32

Physical format ID decoded from the ledger.



Codec(String)

Built-in ledger codec failed.



Compatibility(LedgerCompatibilityError)

Decoded ledger format is not compatible with this reader.



Integrity(LedgerIntegrityError)

Decoded ledger violates structural allocation-history invariants.