pub enum LedgerPayloadEnvelopeError {
Truncated {
actual: usize,
minimum: usize,
},
BadMagic {
found: [u8; 8],
},
PayloadTooLarge {
len: u64,
},
PayloadLengthOverflow {
len: usize,
},
LengthMismatch {
declared: usize,
actual: usize,
},
}Expand description
LedgerPayloadEnvelopeError
Logical payload envelope could not be classified before ledger decode.
Variants
Truncated
Not enough bytes for an envelope header.
BadMagic
Magic bytes do not identify an ic-memory ledger payload.
PayloadTooLarge
Declared payload length does not fit in this platform’s address space.
PayloadLengthOverflow
Declared payload length overflowed the total envelope length.
LengthMismatch
Declared payload length does not match the bytes present.