macro_rules! ic_memory_key {
(authority = $authority:expr, key = $stable_key:literal $(,)?) => { ... };
}Expand description
Declare a key-only request and open it after the host has committed bootstrap.
macro_rules! ic_memory_key {
(authority = $authority:expr, key = $stable_key:literal $(,)?) => { ... };
}Declare a key-only request and open it after the host has committed bootstrap.