CommitStoreDiagnostic

Struct CommitStoreDiagnostic 

pub struct CommitStoreDiagnostic {
    pub slot0: CommitSlotDiagnostic,
    pub slot1: CommitSlotDiagnostic,
    pub authoritative_generation: Option<u64>,
    pub recovery_error: Option<CommitRecoveryError>,
}
CommitStoreDiagnostic

Read-only diagnostic summary of protected commit recovery state.

Fields

slot0: CommitSlotDiagnostic

First physical commit slot diagnostic.

slot1: CommitSlotDiagnostic

Second physical commit slot diagnostic.

authoritative_generation: Option<u64>

Highest valid generation selected by recovery.

recovery_error: Option<CommitRecoveryError>

Recovery error when no authoritative generation can be selected.

Implementations

Source

impl CommitStoreDiagnostic

pub fn from_store<S: DualProtectedCommitStore>(store: &S) -> Self

Build a read-only recovery diagnostic from a dual protected commit store.