ProtectedGenerationSlot

Trait ProtectedGenerationSlot 

pub trait ProtectedGenerationSlot: Eq {
    // Required methods
    fn generation(&self) -> u64;
    fn validates(&self) -> bool;
}
ProtectedGenerationSlot

One physical generation slot that can participate in protected recovery.

This is an advanced low-level API for framework or stable-IO owners. Most callers should use the ledger commit/recovery flow instead of implementing physical slot recovery directly.

Required Methods

fn generation(&self) -> u64

Generation encoded by this slot.

fn validates(&self) -> bool

Return whether the slot passed its marker/checksum validation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors