Structs
- Static
Memory Declaration - StaticMemoryDeclaration
- Static
Memory Range Declaration - StaticMemoryRangeDeclaration
Enums
- Static
Memory Declaration Error - StaticMemoryDeclarationError
Functions
- collect_
static_ memory_ declarations - Add currently registered static allocation declarations to a collector.
- register_
static_ memory_ declaration - Register one allocation declaration before bootstrap seals the snapshot.
- register_
static_ memory_ manager_ declaration - Register one
MemoryManagerdeclaration before bootstrap seals the snapshot. - register_
static_ memory_ manager_ declaration_ with_ schema - Register one
MemoryManagerdeclaration with schema metadata. - register_
static_ memory_ manager_ range - Register one
MemoryManagerauthority range before bootstrap seals the snapshot. - register_
static_ memory_ range_ declaration - Register one authority range declaration before bootstrap seals the snapshot.
- static_
memory_ declaration_ snapshot - Seal currently registered static allocation declarations into a snapshot.
- static_
memory_ declarations - Return the currently registered static allocation declarations.
- static_
memory_ range_ authority - Return the currently registered static range declarations as an authority table.
- static_
memory_ range_ declarations - Return the currently registered static range declarations.