pub fn collect_static_memory_declarations(
collector: &mut DeclarationCollector,
) -> Result<(), StaticMemoryDeclarationError>Expand description
Add currently registered static allocation declarations to a collector.
pub fn collect_static_memory_declarations(
collector: &mut DeclarationCollector,
) -> Result<(), StaticMemoryDeclarationError>Add currently registered static allocation declarations to a collector.