pub fn register_static_memory_range_declaration(
declaration: StaticMemoryRangeDeclaration,
) -> Result<(), StaticMemoryDeclarationError>Expand description
Register one authority range declaration before bootstrap seals the snapshot.
pub fn register_static_memory_range_declaration(
declaration: StaticMemoryRangeDeclaration,
) -> Result<(), StaticMemoryDeclarationError>Register one authority range declaration before bootstrap seals the snapshot.