pub fn static_memory_range_authority() -> Result<MemoryManagerRangeAuthority, StaticMemoryDeclarationError>Expand description
Return the currently registered static range declarations as an authority table.
pub fn static_memory_range_authority() -> Result<MemoryManagerRangeAuthority, StaticMemoryDeclarationError>Return the currently registered static range declarations as an authority table.