Enums
- Runtime
Bootstrap Error - RuntimeBootstrapError
- Runtime
Diagnostic Error - RuntimeDiagnosticError
- Runtime
Open Error - RuntimeOpenError
- Runtime
Policy Error - RuntimePolicyError
Functions
- bootstrap_
default_ memory_ manager - Bootstrap the default
MemoryManager<DefaultMemoryImpl>runtime using generic policy. - bootstrap_
default_ memory_ manager_ with_ policy - Bootstrap the default runtime and layer caller-supplied policy over generic range checks.
- default_
memory_ manager_ commit_ recovery_ diagnostic - Build a protected commit recovery diagnostic for the default ledger store.
- default_
memory_ manager_ diagnostic_ export - Build a diagnostic export for the default
MemoryManagerruntime. - default_
memory_ manager_ doctor_ report - Build a preflight and runtime diagnostic report for the default runtime.
- defer_
eager_ init - Register a pre-bootstrap declaration hook.
- is_
default_ memory_ manager_ bootstrapped - Return true once default runtime bootstrap has completed.
- open_
default_ memory_ manager_ memory - Open a validated
MemoryManagermemory by stable key and expected ID. - validated_
allocations - Return the published validated allocations for the default runtime substrate.