#[non_exhaustive]pub enum RuntimeBootstrapError<P> {
Registry(StaticMemoryDeclarationError),
Range(MemoryManagerRangeAuthorityError),
LedgerIntegrity(LedgerIntegrityError),
LedgerCommit(LedgerCommitError),
StableCellLedger(StableCellLedgerError),
StableCellLedgerWriteTooLarge {
value_size: usize,
},
Validation(AllocationValidationError<RuntimePolicyError<P>>),
Staging(AllocationStageError),
RuntimeLockPoisoned,
}Expand description
RuntimeBootstrapError
Failure to bootstrap the generic ic-memory runtime layer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Registry(StaticMemoryDeclarationError)
Runtime registration or snapshot collection failed.
Range(MemoryManagerRangeAuthorityError)
Runtime range authority table is invalid.
LedgerIntegrity(LedgerIntegrityError)
Runtime ledger genesis construction failed.
LedgerCommit(LedgerCommitError)
Protected ledger recovery or commit failed.
StableCellLedger(StableCellLedgerError)
Stable-cell ledger storage is corrupt before protected recovery can run.
StableCellLedgerWriteTooLarge
Stable-cell ledger storage cannot fit the next protected ledger record.
Validation(AllocationValidationError<RuntimePolicyError<P>>)
Declaration validation failed.
Staging(AllocationStageError)
Validated declarations could not be staged.
RuntimeLockPoisoned
Runtime state lock was poisoned.