default_memory_manager_diagnostic_export

Function default_memory_manager_diagnostic_export 

pub fn default_memory_manager_diagnostic_export() -> Result<DiagnosticExport, RuntimeDiagnosticError>
Build a diagnostic export for the default MemoryManager runtime.

Each allocation record includes the live VirtualMemory::size() for its slot when the committed ledger can be recovered. The reported size is the virtual memory size in WebAssembly pages and bytes, not logical data bytes stored by a particular stable-structure collection.