pub fn validated_allocations() -> Result<ValidatedAllocations, RuntimeOpenError>Expand description
Return the published validated allocations for the default runtime substrate.
pub fn validated_allocations() -> Result<ValidatedAllocations, RuntimeOpenError>Return the published validated allocations for the default runtime substrate.