StableCellPayloadError

Enum StableCellPayloadError 

pub enum StableCellPayloadError {
    NotStableCell,
    UnsupportedVersion {
        version: u8,
    },
    InvalidLength {
        value_len: u64,
        available_bytes: u64,
    },
    LengthOverflow {
        value_len: u64,
    },
}
StableCellPayloadError

Stable-cell payload decode failure.

Variants



NotStableCell

Memory contents do not start with the stable-cell marker.



UnsupportedVersion

Stable-cell format version is not supported.

Fields

version: u8

Observed stable-cell version.



InvalidLength

Stable-cell header length does not fit inside the memory.

Fields

value_len: u64

Encoded value length.

available_bytes: u64

Available payload bytes in memory.



LengthOverflow

Stable-cell length cannot be represented on the current host.

Fields

value_len: u64

Encoded value length.