pub struct StableCellLedgerRecord { /* private fields */ }Expand description
StableCellLedgerRecord
ic-stable-structures::Cell record containing an ic-memory allocation
ledger commit store.
This is a substrate adapter DTO. It owns no framework policy and does not open application allocations.
Implementations
Sourceimpl StableCellLedgerRecord
impl StableCellLedgerRecord
Sourcepub const fn new(store: LedgerCommitStore) -> Self
pub const fn new(store: LedgerCommitStore) -> Self
Construct a record from a commit store.
Sourcepub const fn store(&self) -> &LedgerCommitStore
pub const fn store(&self) -> &LedgerCommitStore
Borrow the embedded commit store.
Sourcepub const fn store_mut(&mut self) -> &mut LedgerCommitStore
pub const fn store_mut(&mut self) -> &mut LedgerCommitStore
Mutably borrow the embedded commit store.
Sourcepub fn into_store(self) -> LedgerCommitStore
pub fn into_store(self) -> LedgerCommitStore
Consume this record and return the embedded commit store.