DeclarationSnapshotError

Enum DeclarationSnapshotError 

pub enum DeclarationSnapshotError {
    Key(StableKeyError),
    SchemaMetadata(SchemaMetadataError),
    DuplicateStableKey(StableKey),
    DuplicateSlot(AllocationSlotDescriptor),
    EmptyLabel,
    LabelTooLong,
    NonAsciiLabel,
    ControlCharacterLabel,
    EmptyRuntimeFingerprint,
    RuntimeFingerprintTooLong,
    NonAsciiRuntimeFingerprint,
    ControlCharacterRuntimeFingerprint,
}
DeclarationSnapshotError

Declaration snapshot validation failure.

Variants



Key(StableKeyError)

Stable-key grammar failure.



SchemaMetadata(SchemaMetadataError)

Schema metadata encoding failure.



DuplicateStableKey(StableKey)

A stable key appeared more than once in one snapshot.



DuplicateSlot(AllocationSlotDescriptor)

An allocation slot appeared more than once in one snapshot.



EmptyLabel

Present declaration labels must be non-empty.



LabelTooLong

Declaration labels must stay bounded for durable ledger storage.



NonAsciiLabel

Declaration labels must not require Unicode normalization.



ControlCharacterLabel

Declaration labels must be printable metadata.



EmptyRuntimeFingerprint

Present runtime fingerprints must be non-empty.



RuntimeFingerprintTooLong

Runtime fingerprints must stay bounded for durable ledger storage.



NonAsciiRuntimeFingerprint

Runtime fingerprints must not require Unicode normalization.



ControlCharacterRuntimeFingerprint

Runtime fingerprints must be printable metadata.