#[non_exhaustive]pub enum AllocationValidationError<P> {
Snapshot(DeclarationSnapshotError),
Policy(P),
StableKeySlotConflict {
stable_key: StableKey,
historical_slot: MemoryManagerSlot,
declared_slot: MemoryManagerSlot,
},
SlotStableKeyConflict {
slot: MemoryManagerSlot,
historical_key: StableKey,
declared_key: StableKey,
},
RetiredAllocation {
stable_key: StableKey,
slot: MemoryManagerSlot,
},
}Expand description
AllocationValidationError
Failure to validate declarations against policy and historical ledger facts. Recovered ledger integrity is established before this boundary.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Snapshot(DeclarationSnapshotError)
Declaration snapshot was decoded or assembled with invalid DTOs.
Policy(P)
Policy adapter rejected the declaration.
StableKeySlotConflict
Stable key was historically bound to a different slot.
Fields

historical_slot: MemoryManagerSlotHistorical slot for the stable key.

declared_slot: MemoryManagerSlotSlot claimed by the current declaration.
SlotStableKeyConflict
Slot was historically bound to a different stable key.
Fields

slot: MemoryManagerSlotSlot claimed by the current declaration.
RetiredAllocation
Current declaration attempted to revive a retired allocation.