#[non_exhaustive]pub enum AllocationValidationError<P> {
LedgerIntegrity(LedgerIntegrityError),
Snapshot(DeclarationSnapshotError),
Policy(P),
StableKeySlotConflict {
stable_key: StableKey,
historical_slot: Box<AllocationSlotDescriptor>,
declared_slot: Box<AllocationSlotDescriptor>,
},
SlotStableKeyConflict {
slot: Box<AllocationSlotDescriptor>,
historical_key: StableKey,
declared_key: StableKey,
},
RetiredAllocation {
stable_key: StableKey,
slot: Box<AllocationSlotDescriptor>,
},
UnexpectedActiveAllocationConflict {
stable_key: StableKey,
slot: Box<AllocationSlotDescriptor>,
},
}Expand description
AllocationValidationError
Failure to validate declarations against policy and historical ledger facts.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
LedgerIntegrity(LedgerIntegrityError)
Historical ledger was decoded or assembled with invalid committed state.
Snapshot(DeclarationSnapshotError)
Declaration snapshot was decoded or assembled with invalid DTOs.
Policy(P)
Policy adapter rejected the declaration.
StableKeySlotConflict
Stable key was historically bound to a different slot.
Fields
historical_slot: Box<AllocationSlotDescriptor>Historical slot for the stable key.
declared_slot: Box<AllocationSlotDescriptor>Slot claimed by the current declaration.
SlotStableKeyConflict
Slot was historically bound to a different stable key.
Fields
slot: Box<AllocationSlotDescriptor>Slot claimed by the current declaration.
RetiredAllocation
Current declaration attempted to revive a retired allocation.
Fields
slot: Box<AllocationSlotDescriptor>Retired allocation slot.
UnexpectedActiveAllocationConflict
Internal claim validation reported an active-allocation conflict where declaration validation expected only move, reuse, or tombstone conflicts.
Fields
slot: Box<AllocationSlotDescriptor>Active allocation slot.