#[non_exhaustive]pub enum RuntimeBootstrapError<P> {
EmptyPolicyIdentity,
DeclarationSnapshotMismatch,
PolicyIdentityMismatch {
established: &'static str,
requested: &'static str,
},
Registry(StaticMemoryDeclarationError),
LedgerIntegrity(LedgerIntegrityError),
LedgerCommit(LedgerCommitError),
StableCellLedger(StableCellLedgerError),
StableCellLedgerWriteTooLarge {
value_size: usize,
},
Validation(AllocationValidationError<RuntimePolicyError<P>>),
Staging(AllocationStageError),
State(RuntimeStateError),
}Expand description
RuntimeBootstrapError
Failure to bootstrap one MemoryRuntime.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyPolicyIdentity
The policy did not provide a usable semantic bootstrap identity.
DeclarationSnapshotMismatch
A bootstrapped runtime was called with a different declaration snapshot.
PolicyIdentityMismatch
A bootstrapped runtime was called with a different policy identity.
Fields
Registry(StaticMemoryDeclarationError)
Linked-program declaration snapshot sealing failed.
LedgerIntegrity(LedgerIntegrityError)
Runtime ledger genesis construction failed.
LedgerCommit(LedgerCommitError)
Protected ledger recovery or commit failed.
StableCellLedger(StableCellLedgerError)
Stable-cell ledger storage is corrupt before protected recovery can run.
StableCellLedgerWriteTooLarge
Stable-cell ledger storage cannot fit the next protected ledger record.
Validation(AllocationValidationError<RuntimePolicyError<P>>)
Declaration validation failed.
Staging(AllocationStageError)
Validated declarations could not be staged.
State(RuntimeStateError)
Runtime lifecycle or default TLS access failed.