#[non_exhaustive]pub enum RuntimeStateError {
Construction(RuntimeConstructionError),
ReentrantAccess,
Unavailable,
InconsistentLifecycle,
}Expand description
RuntimeStateError
Failure to enter or maintain one memory runtime’s in-memory lifecycle.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Construction(RuntimeConstructionError)
This thread’s default runtime could not safely claim its backing memory.
ReentrantAccess
A default-runtime operation re-entered while that TLS runtime was borrowed.
The thread-local default runtime is being destroyed and cannot be entered.
InconsistentLifecycle
Internal runtime lifecycle state was inconsistent.