pub fn committed_allocations() -> Result<CommittedAllocations, RuntimeOpenError>Expand description
Return the published committed allocations for the default runtime substrate.
pub fn committed_allocations() -> Result<CommittedAllocations, RuntimeOpenError>Return the published committed allocations for the default runtime substrate.