AllocationReservationError

Enum AllocationReservationError 

pub enum AllocationReservationError {
    GenerationOverflow {
        generation: u64,
    },
    TooManyReservations {
        count: usize,
    },
    InvalidSchemaMetadata {
        stable_key: StableKey,
        error: SchemaMetadataError,
    },
    StableKeySlotConflict {
        stable_key: StableKey,
        historical_slot: Box<AllocationSlotDescriptor>,
        reserved_slot: Box<AllocationSlotDescriptor>,
    },
    SlotStableKeyConflict {
        slot: Box<AllocationSlotDescriptor>,
        historical_key: StableKey,
        reserved_key: StableKey,
    },
    ActiveAllocation {
        stable_key: StableKey,
        slot: Box<AllocationSlotDescriptor>,
    },
    RetiredAllocation {
        stable_key: StableKey,
        slot: Box<AllocationSlotDescriptor>,
    },
}
AllocationReservationError

Failure to stage a reservation generation.

Variants



GenerationOverflow

Ledger generation cannot be advanced without overflow.

Fields

generation: u64

Current ledger generation.



TooManyReservations

Declaration count does not fit in durable generation diagnostics.

Fields

count: usize

Number of reservations in the staged generation.



InvalidSchemaMetadata

A staged reservation carries invalid schema metadata.

Fields

stable_key: StableKey

Stable key whose schema metadata is invalid.

error: SchemaMetadataError

Schema metadata validation error.



StableKeySlotConflict

Stable key was historically bound to a different slot.

Fields

stable_key: StableKey

Stable key being reserved.

historical_slot: Box<AllocationSlotDescriptor>

Historical slot for the stable key.

reserved_slot: Box<AllocationSlotDescriptor>

Slot claimed by the reservation.



SlotStableKeyConflict

Slot was historically bound to a different stable key.

Fields

slot: Box<AllocationSlotDescriptor>

Slot being reserved.

historical_key: StableKey

Historical stable key for the slot.

reserved_key: StableKey

Stable key claimed by the reservation.



ActiveAllocation

Allocation already exists as an active record.

Fields

stable_key: StableKey

Active stable key.

slot: Box<AllocationSlotDescriptor>

Active allocation slot.



RetiredAllocation

Allocation was already retired and cannot be reserved.

Fields

stable_key: StableKey

Retired stable key.

slot: Box<AllocationSlotDescriptor>

Retired allocation slot.