pub enum AllocationReservationError {
GenerationOverflow {
generation: u64,
},
InvalidSchemaMetadata {
stable_key: StableKey,
error: SchemaMetadataError,
},
StableKeySlotConflict {
stable_key: StableKey,
historical_slot: Box<AllocationSlotDescriptor>,
reserved_slot: Box<AllocationSlotDescriptor>,
},
SlotStableKeyConflict {
slot: Box<AllocationSlotDescriptor>,
historical_key: StableKey,
reserved_key: StableKey,
},
ActiveAllocation {
stable_key: StableKey,
slot: Box<AllocationSlotDescriptor>,
},
RetiredAllocation {
stable_key: StableKey,
slot: Box<AllocationSlotDescriptor>,
},
}Expand description
AllocationReservationError
Failure to stage a reservation generation.
Variants
GenerationOverflow
Ledger generation cannot be advanced without overflow.
InvalidSchemaMetadata
A staged reservation carries invalid schema metadata.
Fields

error: SchemaMetadataErrorSchema metadata validation error.
StableKeySlotConflict
Stable key was historically bound to a different slot.
Fields

historical_slot: Box<AllocationSlotDescriptor>Historical slot for the stable key.

reserved_slot: Box<AllocationSlotDescriptor>Slot claimed by the reservation.
SlotStableKeyConflict
Slot was historically bound to a different stable key.
Fields

slot: Box<AllocationSlotDescriptor>Slot being reserved.
ActiveAllocation
Allocation already exists as an active record.
Fields

slot: Box<AllocationSlotDescriptor>Active allocation slot.
RetiredAllocation
Allocation was already retired and cannot be reserved.
Fields

slot: Box<AllocationSlotDescriptor>Retired allocation slot.