LedgerIntegrityError

Enum LedgerIntegrityError 

pub enum LedgerIntegrityError {
Show 19 variants DuplicateStableKey { stable_key: StableKey, }, DuplicateSlot { slot: Box<AllocationSlotDescriptor>, }, InvalidRecordGenerationOrder { stable_key: StableKey, first_generation: u64, last_seen_generation: u64, }, FutureRecordGeneration { stable_key: StableKey, generation: u64, current_generation: u64, }, UnexpectedRetiredGeneration { stable_key: StableKey, }, MissingRetiredGeneration { stable_key: StableKey, }, RetiredBeforeFirstGeneration { stable_key: StableKey, first_generation: u64, retired_generation: u64, }, EmptySchemaHistory { stable_key: StableKey, }, NonIncreasingSchemaHistory { stable_key: StableKey, }, SchemaHistoryOutOfBounds { stable_key: StableKey, generation: u64, }, InvalidSchemaMetadata { stable_key: StableKey, generation: u64, error: SchemaMetadataError, }, DuplicateGeneration { generation: u64, }, FutureGeneration { generation: u64, current_generation: u64, }, InvalidParentGeneration { generation: u64, parent_generation: Option<u64>, }, MissingCurrentGenerationRecord { current_generation: u64, }, NonIncreasingGenerationRecords { generation: u64, }, BrokenGenerationChain { generation: u64, expected_parent: Option<u64>, actual_parent: Option<u64>, }, UnknownRecordGeneration { stable_key: StableKey, generation: u64, }, DiagnosticMetadata(DeclarationSnapshotError),
}
LedgerIntegrityError

Decoded ledger violates structural allocation-history invariants.

Variants



DuplicateStableKey

Stable key appears in more than one allocation record.

Fields

stable_key: StableKey

Duplicate stable key.



DuplicateSlot

Allocation slot appears in more than one allocation record.

Fields

slot: Box<AllocationSlotDescriptor>

Duplicate allocation slot.



InvalidRecordGenerationOrder

Allocation record generation ordering is invalid.

Fields

stable_key: StableKey

Stable key whose record is invalid.

first_generation: u64

First generation in the record.

last_seen_generation: u64

Last seen generation in the record.



FutureRecordGeneration

Allocation record points past the current generation.

Fields

stable_key: StableKey

Stable key whose record is invalid.

generation: u64

Generation referenced by the record.

current_generation: u64

Current ledger generation.



UnexpectedRetiredGeneration

Non-retired allocation carries retired metadata.

Fields

stable_key: StableKey

Stable key whose record is invalid.



MissingRetiredGeneration

Retired allocation is missing retired metadata.

Fields

stable_key: StableKey

Stable key whose record is invalid.



RetiredBeforeFirstGeneration

Retired generation predates the allocation record.

Fields

stable_key: StableKey

Stable key whose record is invalid.

first_generation: u64

First generation in the record.

retired_generation: u64

Retired generation in the record.



EmptySchemaHistory

Allocation record has no schema metadata history.

Fields

stable_key: StableKey

Stable key whose record is invalid.



NonIncreasingSchemaHistory

Schema metadata generation history is not strictly increasing.

Fields

stable_key: StableKey

Stable key whose record is invalid.



SchemaHistoryOutOfBounds

Schema metadata generation is outside the allocation record lifetime.

Fields

stable_key: StableKey

Stable key whose record is invalid.

generation: u64

Schema metadata generation.



InvalidSchemaMetadata

Schema metadata in committed allocation history is invalid.

Fields

stable_key: StableKey

Stable key whose schema metadata is invalid.

generation: u64

Generation that recorded the invalid schema metadata.

error: SchemaMetadataError

Schema metadata validation error.



DuplicateGeneration

Generation record appears more than once.

Fields

generation: u64

Duplicate generation.



FutureGeneration

Generation record points past the current generation.

Fields

generation: u64

Generation record value.

current_generation: u64

Current ledger generation.



InvalidParentGeneration

Generation parent does not precede the child generation.

Fields

generation: u64

Generation record value.

parent_generation: Option<u64>

Invalid parent generation.



MissingCurrentGenerationRecord

Current ledger generation has no committed generation record.

Fields

current_generation: u64

Current ledger generation.



NonIncreasingGenerationRecords

Generation records are not strictly increasing in durable order.

Fields

generation: u64

Non-increasing generation.



BrokenGenerationChain

Generation record parent does not match the previous committed generation.

Fields

generation: u64

Generation whose parent link is invalid.

expected_parent: Option<u64>

Expected parent generation.

actual_parent: Option<u64>

Actual parent generation.



UnknownRecordGeneration

Allocation record refers to a generation absent from committed history.

Fields

stable_key: StableKey

Stable key whose record is invalid.

generation: u64

Unknown generation.



DiagnosticMetadata(DeclarationSnapshotError)

Generation diagnostic metadata is invalid.