pub struct AllocationLedger {
pub ledger_schema_version: u32,
pub physical_format_id: u32,
pub current_generation: u64,
pub allocation_history: AllocationHistory,
}Expand description
AllocationLedger
Durable root of allocation history.
Fields
ledger_schema_version: u32Ledger schema version.
physical_format_id: u32Physical encoding format identifier.
current_generation: u64Current committed generation selected by recovery.
allocation_history: AllocationHistoryHistorical allocation facts.
Implementations
Sourceimpl AllocationLedger
impl AllocationLedger
Sourcepub fn validate_integrity(&self) -> Result<(), LedgerIntegrityError>
pub fn validate_integrity(&self) -> Result<(), LedgerIntegrityError>
Validate structural ledger invariants before recovery or commit.
Sourcepub fn stage_validated_generation(
&self,
validated: &ValidatedAllocations,
committed_at: Option<u64>,
) -> Self
pub fn stage_validated_generation( &self, validated: &ValidatedAllocations, committed_at: Option<u64>, ) -> Self
Return a copy of the ledger with validated recorded as the next generation.
This is a pure logical update. Physical atomicity is the responsibility of the substrate commit protocol.
Sourcepub fn stage_reservation_generation(
&self,
reservations: &[AllocationDeclaration],
committed_at: Option<u64>,
) -> Result<Self, AllocationReservationError>
pub fn stage_reservation_generation( &self, reservations: &[AllocationDeclaration], committed_at: Option<u64>, ) -> Result<Self, AllocationReservationError>
Return a copy of the ledger with reservations recorded as the next generation.
This is a pure logical update. The caller is responsible for applying framework policy before staging reservations.
Sourcepub fn stage_retirement_generation(
&self,
retirement: &AllocationRetirement,
committed_at: Option<u64>,
) -> Result<Self, AllocationRetirementError>
pub fn stage_retirement_generation( &self, retirement: &AllocationRetirement, committed_at: Option<u64>, ) -> Result<Self, AllocationRetirementError>
Return a copy of the ledger with one explicit retirement committed.