pub struct CommitStoreDiagnostic {
pub slot0: CommitSlotDiagnostic,
pub slot1: CommitSlotDiagnostic,
pub authoritative_generation: Option<u64>,
pub recovery_error: Option<CommitRecoveryError>,
}Expand description
CommitStoreDiagnostic
Read-only diagnostic summary of protected commit recovery state.
Fields
slot0: CommitSlotDiagnosticFirst physical commit slot diagnostic.
slot1: CommitSlotDiagnosticSecond physical commit slot diagnostic.
Highest valid generation selected by recovery.
recovery_error: Option<CommitRecoveryError>Recovery error when no authoritative generation can be selected.
Implementations
Sourceimpl CommitStoreDiagnostic
impl CommitStoreDiagnostic
Sourcepub fn from_store<S: DualProtectedCommitStore>(store: &S) -> Self
pub fn from_store<S: DualProtectedCommitStore>(store: &S) -> Self
Build a read-only recovery diagnostic from a dual protected commit store.