pub trait ProtectedGenerationSlot: Eq {
// Required methods
fn generation(&self) -> u64;
fn validates(&self) -> bool;
}Expand description
ProtectedGenerationSlot
One physical generation slot that can participate in protected recovery.
This is an advanced low-level API for framework or stable-IO owners. Most callers should use the ledger commit/recovery flow instead of implementing physical slot recovery directly.
Required Methods
Sourcefn generation(&self) -> u64
fn generation(&self) -> u64
Generation encoded by this slot.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".