Module registry

Module registry 

Structs

StaticMemoryDeclaration
StaticMemoryDeclaration
StaticMemoryRangeDeclaration
StaticMemoryRangeDeclaration

Enums

StaticMemoryDeclarationError
StaticMemoryDeclarationError

Functions

collect_static_memory_declarations
Add currently registered static allocation declarations to a collector.
register_static_memory_declaration
Register one allocation declaration before bootstrap seals the snapshot.
register_static_memory_manager_declaration
Register one MemoryManager declaration before bootstrap seals the snapshot.
register_static_memory_manager_declaration_with_schema
Register one MemoryManager declaration with schema metadata.
register_static_memory_manager_range
Register one MemoryManager authority range before bootstrap seals the snapshot.
register_static_memory_range_declaration
Register one authority range declaration before bootstrap seals the snapshot.
static_memory_declaration_snapshot
Seal currently registered static allocation declarations into a snapshot.
static_memory_declarations
Return the currently registered static allocation declarations.
static_memory_range_authority
Return the currently registered static range declarations as an authority table.
static_memory_range_declarations
Return the currently registered static range declarations.