static_memory_declaration_snapshot

Function static_memory_declaration_snapshot 

pub fn static_memory_declaration_snapshot() -> Result<DeclarationSnapshot, StaticMemoryDeclarationError>
Seal currently registered static allocation declarations into a snapshot.

Sealing prevents later static registrations from being accepted. Callers may still call this function again to rebuild the same snapshot for idempotent bootstrap paths.