Module slot

Module slot 

Structs

AllocationSlotDescriptor
AllocationSlotDescriptor
MemoryManagerIdRange
MemoryManagerIdRange

Enums

AllocationSlot
AllocationSlot
MemoryManagerRangeError
MemoryManagerRangeError
MemoryManagerSlotError
MemoryManagerSlotError

Constants

IC_MEMORY_AUTHORITY_OWNER
Diagnostic owner label for ic-memory allocation-governance infrastructure.
IC_MEMORY_AUTHORITY_PURPOSE
Diagnostic purpose for the ic-memory allocation-governance authority range.
IC_MEMORY_LEDGER_LABEL
Diagnostic label of the allocation ledger when backed by the current MemoryManager substrate.
IC_MEMORY_LEDGER_STABLE_KEY
Stable key of the allocation ledger when backed by the current MemoryManager substrate.
IC_MEMORY_STABLE_KEY_PREFIX
Stable-key namespace prefix reserved for ic-memory allocation-governance infrastructure.
MEMORY_MANAGER_DESCRIPTOR_VERSION
Descriptor version for current MemoryManagerId slots.
MEMORY_MANAGER_GOVERNANCE_MAX_ID
Last MemoryManager ID reserved for ic-memory governance in the current substrate.
MEMORY_MANAGER_INVALID_ID
MemoryManager unallocated-bucket sentinel. This is not a usable slot.
MEMORY_MANAGER_LEDGER_ID
MemoryManager ID used by the allocation ledger in the current MemoryManager substrate.
MEMORY_MANAGER_MAX_ID
Last usable MemoryManager virtual memory ID.
MEMORY_MANAGER_MIN_ID
First usable MemoryManager virtual memory ID.
MEMORY_MANAGER_SUBSTRATE
Substrate identifier for ic-stable-structures::MemoryManager slots.

Functions

is_ic_memory_stable_key
Return true when stable_key belongs to the ic-memory namespace.
memory_manager_governance_range
MemoryManager range reserved for ic-memory governance in the current substrate.
validate_memory_manager_id
Validate that a MemoryManager ID is usable as an allocation slot.