pub enum MemoryManagerRangeAuthorityError {
Range(MemoryManagerRangeError),
Slot(MemoryManagerSlotError),
OverlappingRanges {
existing_start: u8,
existing_end: u8,
candidate_start: u8,
candidate_end: u8,
},
InvalidDiagnosticString {
field: &'static str,
reason: &'static str,
},
UnclaimedId {
id: u8,
},
AuthorityMismatch {
id: u8,
expected_authority: String,
actual_authority: String,
},
ModeMismatch {
id: u8,
authority: String,
expected_mode: MemoryManagerRangeMode,
actual_mode: MemoryManagerRangeMode,
},
MissingCoverage {
start: u8,
end: u8,
},
RangeOutsideCoverageTarget {
start: u8,
end: u8,
target_start: u8,
target_end: u8,
},
}Expand description
MemoryManagerRangeAuthorityError
Invalid MemoryManager range authority policy.
Variants
Range(MemoryManagerRangeError)
Authority range bounds are invalid.
Slot(MemoryManagerSlotError)
Slot descriptor is not a usable MemoryManager ID slot.
OverlappingRanges
Authority range overlaps an existing range.
Fields
InvalidDiagnosticString
Authority or purpose text failed diagnostic string validation.
UnclaimedId
No authority range covers the requested ID.
AuthorityMismatch
Slot is governed by a different authority.
ModeMismatch
Slot is governed by the expected authority with a different mode.
Fields
Authority identifier.

expected_mode: MemoryManagerRangeModeExpected authority mode.

actual_mode: MemoryManagerRangeModeActual authority mode.
MissingCoverage
A complete coverage target has no authority records for part of it.
RangeOutsideCoverageTarget
An authority record lies outside the complete coverage target.