MemoryManagerRangeAuthorityError

Enum MemoryManagerRangeAuthorityError 

pub enum MemoryManagerRangeAuthorityError {
    Range(MemoryManagerRangeError),
    Slot(MemoryManagerSlotError),
    OverlappingRanges {
        existing_start: u8,
        existing_end: u8,
        candidate_start: u8,
        candidate_end: u8,
    },
    InvalidDiagnosticString {
        field: &'static str,
        reason: &'static str,
    },
    UnclaimedId {
        id: u8,
    },
    AuthorityMismatch {
        id: u8,
        expected_authority: String,
        actual_authority: String,
    },
    ModeMismatch {
        id: u8,
        authority: String,
        expected_mode: MemoryManagerRangeMode,
        actual_mode: MemoryManagerRangeMode,
    },
    MissingCoverage {
        start: u8,
        end: u8,
    },
    RangeOutsideCoverageTarget {
        start: u8,
        end: u8,
        target_start: u8,
        target_end: u8,
    },
}
MemoryManagerRangeAuthorityError

Invalid MemoryManager range authority policy.

Variants



Range(MemoryManagerRangeError)

Authority range bounds are invalid.



Slot(MemoryManagerSlotError)

Slot descriptor is not a usable MemoryManager ID slot.



OverlappingRanges

Authority range overlaps an existing range.

Fields

existing_start: u8

Existing range start.

existing_end: u8

Existing range end.

candidate_start: u8

Candidate range start.

candidate_end: u8

Candidate range end.



InvalidDiagnosticString

Authority or purpose text failed diagnostic string validation.

Fields

field: &'static str

Diagnostic field name.

reason: &'static str

Validation failure.



UnclaimedId

No authority range covers the requested ID.

Fields

id: u8

Unclaimed MemoryManager ID.



AuthorityMismatch

Slot is governed by a different authority.

Fields

id: u8

MemoryManager ID.

expected_authority: String

Expected authority identifier.

actual_authority: String

Actual authority identifier.



ModeMismatch

Slot is governed by the expected authority with a different mode.

Fields

id: u8

MemoryManager ID.

authority: String

Authority identifier.

expected_mode: MemoryManagerRangeMode

Expected authority mode.

actual_mode: MemoryManagerRangeMode

Actual authority mode.



MissingCoverage

A complete coverage target has no authority records for part of it.

Fields

start: u8

First missing ID.

end: u8

Last missing ID.



RangeOutsideCoverageTarget

An authority record lies outside the complete coverage target.

Fields

start: u8

Authority range start.

end: u8

Authority range end.

target_start: u8

Coverage target start.

target_end: u8

Coverage target end.