pub enum StableCellPayloadError {
NotStableCell,
UnsupportedVersion {
version: u8,
},
InvalidLength {
value_len: u64,
available_bytes: u64,
},
LengthOverflow {
value_len: u64,
},
}Expand description
StableCellPayloadError
Stable-cell payload decode failure.
Variants
NotStableCell
Memory contents do not start with the stable-cell marker.
UnsupportedVersion
Stable-cell format version is not supported.
InvalidLength
Stable-cell header length does not fit inside the memory.
LengthOverflow
Stable-cell length cannot be represented on the current host.