StorageSubstrate

Trait StorageSubstrate 

pub trait StorageSubstrate {
    type Slot;
    type LedgerMemory;
    type MemoryHandle;
    type Error;

    // Required methods
    fn open_ledger(&self) -> Result<Self::LedgerMemory, Self::Error>;
    fn open_slot(
        &self,
        slot: &AllocationSlotDescriptor,
    ) -> Result<Self::MemoryHandle, Self::Error>;
    fn describe_slot(&self, slot: &Self::Slot) -> AllocationSlotDescriptor;
}
StorageSubstrate

Physical storage provider for the ledger anchor and allocation slots.

Required Associated Types

type Slot

Native slot type accepted by this substrate.

type LedgerMemory

Ledger memory handle.

type MemoryHandle

Allocation memory handle.

type Error

Substrate error type.

Required Methods

fn open_ledger(&self) -> Result<Self::LedgerMemory, Self::Error>

Open the ledger anchor.

fn open_slot( &self, slot: &AllocationSlotDescriptor, ) -> Result<Self::MemoryHandle, Self::Error>

Open an allocation slot after validation has produced a session.

fn describe_slot(&self, slot: &Self::Slot) -> AllocationSlotDescriptor

Describe a native slot as a durable allocation slot descriptor.

Implementors