AllocationValidationError

Enum AllocationValidationError 

pub enum AllocationValidationError<P> {
    Policy(P),
    StableKeySlotConflict {
        stable_key: StableKey,
        historical_slot: Box<AllocationSlotDescriptor>,
        declared_slot: Box<AllocationSlotDescriptor>,
    },
    SlotStableKeyConflict {
        slot: Box<AllocationSlotDescriptor>,
        historical_key: StableKey,
        declared_key: StableKey,
    },
    RetiredAllocation {
        stable_key: StableKey,
        slot: Box<AllocationSlotDescriptor>,
    },
}
AllocationValidationError

Failure to validate declarations against policy and historical ledger facts.

Variants



Policy(P)

Policy adapter rejected the declaration.



StableKeySlotConflict

Stable key was historically bound to a different slot.

Fields

stable_key: StableKey

Stable key that was redeclared.

historical_slot: Box<AllocationSlotDescriptor>

Historical slot for the stable key.

declared_slot: Box<AllocationSlotDescriptor>

Slot claimed by the current declaration.



SlotStableKeyConflict

Slot was historically bound to a different stable key.

Fields

slot: Box<AllocationSlotDescriptor>

Slot claimed by the current declaration.

historical_key: StableKey

Historical stable key for the slot.

declared_key: StableKey

Stable key claimed by the current declaration.



RetiredAllocation

Current declaration attempted to revive a retired allocation.

Fields

stable_key: StableKey

Retired stable key.

slot: Box<AllocationSlotDescriptor>

Retired allocation slot.